gcpauth

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package gcpauth provides shared GCP authentication utilities.

Index

Constants

const ProxyEnvVar = "AI_GATEWAY_GCP_AUTH_PROXY_URL"

ProxyEnvVar is the environment variable name for configuring the GCP auth proxy URL.

Variables

This section is empty.

Functions

func MustNewTransport

func MustNewTransport() http.RoundTripper

MustNewTransport is like NewTransport but panics on error. This is useful for package-level variable initialization.

func NewTransport

func NewTransport() (http.RoundTripper, error)

NewTransport returns an http.RoundTripper configured with proxy support if AI_GATEWAY_GCP_AUTH_PROXY_URL is set. If the environment variable is not set, it returns a default http.Transport.

Types

This section is empty.

Jump to